module Types.Values
  ( String(..)
  , FilePath
  , Image(..)
  , ImageConversionSettings(..)
  , Template(..)
  ) where

import Prelude hiding (String, FilePath)
import qualified Prelude

import Data.String (IsString(..))
import Data.Text (Text)
import qualified Codec.Picture as CP
import Language.Haskell.TH.Syntax (Lift(..))

newtype String = StringWrapper Prelude.String
  deriving (Eq, Lift)

instance Show String where
  show (StringWrapper s) = show s

type FilePath = String

instance IsString String where
  fromString = StringWrapper

newtype Image = ImageWrapper (CP.Image CP.PixelRGB8)
  deriving (Eq)

instance Show Image where
  show = const "Image"

instance Lift Image where
  liftTyped _ = error "cannot lift images"

data ImageConversionSettings = ResizeToWidth Int
  deriving (Eq, Show, Lift)

data Template = TemplateParts Text Text
  deriving (Eq, Show, Lift)
